# zyx

`zyx` is a fundamentally different (and much more fun may I add), way to interact with language and
embedding models to define and iterate through workflows, agents, and more.

## Installation

```bash
pip install zyx
```
